@@ -236,7 +236,7 @@ extern int                max_sched_loops         _DEFVAL(MAX_SCHED_LOOPS_PER_CY
 extern unsigned int       global_t2               _DEFVAL(DEFAULT_T2_TIMER_VALUE);
 
 extern char               local_ip[40];
-extern char               local_ip_escaped[42];
+extern char               local_ip_escaped[42];   /* with [brackets] in case of IPv6 */
 extern bool               local_ip_is_ipv6;
 extern int                local_port              _DEFVAL(0);
 #ifdef USE_SCTP
@@ -264,13 +264,12 @@ extern int                rtp_buffsize            _DEFVAL(65535);
 
 extern bool               rtp_echo_enabled        _DEFVAL(0);
 extern char               media_ip[40];
-extern char               media_ip_escaped[42];
 extern int                user_media_port         _DEFVAL(0);
 extern int                media_port              _DEFVAL(0);
 extern size_t             media_bufsize           _DEFVAL(2048);
 extern_c bool             media_ip_is_ipv6        _DEFVAL(false);
 extern char               remote_ip[40];
-extern char               remote_ip_escaped[42];
+extern char               remote_ip_escaped[42];  /* with [brackets] in case of IPv6 */
 extern int                remote_port             _DEFVAL(DEFAULT_PORT);
 extern unsigned int       pid                     _DEFVAL(0);
 extern bool               print_all_responses     _DEFVAL(false);
@@ -428,8 +427,8 @@ extern  int stepDynamicId   _DEFVAL(4);      // step of increment for dynamicId
 extern struct sipp_socket *main_socket            _DEFVAL(NULL);
 extern struct sipp_socket *main_remote_socket     _DEFVAL(NULL);
 extern struct sipp_socket *tcp_multiplex          _DEFVAL(NULL);
-extern int           media_socket                 _DEFVAL(0);
-extern int           media_socket_video           _DEFVAL(0);
+extern int media_socket_audio                     _DEFVAL(0);
+extern int media_socket_video                     _DEFVAL(0);
 
 extern struct sockaddr_storage  local_sockaddr;
 extern struct sockaddr_storage  localTwin_sockaddr;
