@@ -338,7 +338,7 @@ const char *sip_tls_error_string(SSL *ssl, int size)
 
 static char* get_inet_address(const struct sockaddr_storage* addr, char* dst, int len)
 {
-    if (getnameinfo(_RCAST(struct sockaddr*, addr), sizeof(*addr),
+    if (getnameinfo(_RCAST(struct sockaddr*, addr), SOCK_ADDR_SIZE(addr),
                     dst, len, NULL, 0, NI_NUMERICHOST) != 0) {
         snprintf(dst, len, "addr not supported");
     }
@@ -1694,7 +1694,12 @@ void sipp_sctp_peer_params(struct sipp_socket *socket)
         memset(&peerparam, 0, sizeof(peerparam));
 
         sockaddr* addresses;
+#ifdef __SUNOS
+        /* Sun takes a void** instead of a struct sockaddr** */
+        int addresscount = sctp_getpaddrs(socket->ss_fd, 0, (void**)&addresses);
+#else
         int addresscount = sctp_getpaddrs(socket->ss_fd, 0, &addresses);
+#endif
         if (addresscount < 1) WARNING("sctp_getpaddrs, errno=%d", errno);
 
         for (int i = 0; i < addresscount; i++) {
@@ -1887,7 +1892,14 @@ int read_error(struct sipp_socket *socket, int ret)
     const char *errstring = strerror(errno);
 #ifdef USE_OPENSSL
     if (socket->ss_transport == T_TLS) {
+        int err = SSL_get_error(socket->ss_ssl, ret);
         errstring = sip_tls_error_string(socket->ss_ssl, ret);
+        if (err == SSL_ERROR_WANT_READ) {
+            /* This is benign - we just need to wait for the socket to be
+             * readable again, which will happen naturally as part of the
+             * poll/epoll loop. */
+            return 1;
+        }
     }
 #endif
 
@@ -1900,8 +1912,10 @@ int read_error(struct sipp_socket *socket, int ret)
     }
 #endif
 
-    /* We have only non-blocking reads, so this should not occur. */
-    if (ret < 0) {
+    /* We have only non-blocking reads, so this should not occur. The OpenSSL
+     * functions don't set errno, though, so this check doesn't make sense
+     * for TLS sockets. */
+    if ((ret < 0) && (socket->ss_transport != T_TLS)) {
         assert(errno != EAGAIN);
     }
 
@@ -2527,11 +2541,11 @@ int open_connections()
         }
         freeaddrinfo(local_addr);
 
-        if (local_sockaddr.ss_family == AF_INET6) {
+        if (local_sockaddr.ss_family == AF_INET) {
+            strcpy(local_ip_escaped, local_ip);
+        } else {
             local_ip_is_ipv6 = true;
             sprintf(local_ip_escaped, "[%s]", local_ip);
-        } else {
-            strcpy(local_ip_escaped, local_ip);
         }
     }
 
